@@ -1,26 +1,16 @@
 from pkg_resources import get_distribution, DistributionNotFound
 import os.path
-from .stump import (  # noqa: F401
-    stump,
-    _stump,
-)
+from .stump import stump  # noqa: F401
 from .stumped import stumped  # noqa: F401
-from .mstump import (  # noqa: F401
-    mstump,
-    _mstump,
-    _query_mstump_profile,
-    _get_first_mstump_profile,
-    _get_multi_QT,
-    _multi_mass,
-    _apply_include,
-)
+from .mstump import mstump, subspace  # noqa: F401
 from .mstumped import mstumped  # noqa: F401
-from .aamp import aamp, _aamp  # noqa: F401
+from .aamp import aamp  # noqa: F401
 from .aamped import aamped  # noqa: F401
 from .aampi import aampi  # noqa: F401
 from .chains import atsc, allc  # noqa: F401
-from .floss import floss, fluss, _nnmark, _iac, _cac, _rea  # noqa: F401
-from .ostinato import ostinato  # noqa: F401
+from .floss import floss, fluss  # noqa: F401
+from .ostinato import ostinato, ostinatoed  # noqa: F401
+from .aamp_ostinato import aamp_ostinato, aamp_ostinatoed  # noqa: F401
 from .scrump import scrump  # noqa: F401
 from .stumpi import stumpi  # noqa: F401
 from .mpdist import mpdist, mpdisted  # noqa: F401
@@ -30,11 +20,17 @@ from numba import cuda
 if cuda.is_available():
     from .gpu_stump import gpu_stump  # noqa: F401
     from .gpu_aamp import gpu_aamp  # noqa: F401
+    from .gpu_ostinato import gpu_ostinato  # noqa: F401
+    from .gpu_aamp_ostinato import gpu_aamp_ostinato  # noqa: F401
     from .gpu_mpdist import gpu_mpdist  # noqa: F401
     from .gpu_aampdist import gpu_aampdist  # noqa: F401
 else:  # pragma: no cover
     from .core import _gpu_stump_driver_not_found as gpu_stump  # noqa: F401
     from .core import _gpu_aamp_driver_not_found as gpu_aamp  # noqa: F401
+    from .core import _gpu_ostinato_driver_not_found as gpu_ostinato  # noqa: F401
+    from .core import (
+        _gpu_aamp_ostinato_driver_not_found as gpu_aamp_ostinato,
+    )  # noqa: F401
     from .core import _gpu_mpdist_driver_not_found as gpu_mpdist  # noqa: F401
     from .core import _gpu_aampdist_driver_not_found as gpu_aampdist  # noqa: F401
     import ast
@@ -70,6 +66,36 @@ else:  # pragma: no cover
         if fd.name == "gpu_aamp":
             gpu_aamp.__doc__ = ast.get_docstring(fd)
 
+    # Fix GPU-OSTINATO Docs
+    gpu_ostinato.__doc__ = ""
+    filepath = pathlib.Path(__file__).parent / "gpu_ostinato.py"
+
+    file_contents = ""
+    with open(filepath, encoding="utf8") as f:
+        file_contents = f.read()
+    module = ast.parse(file_contents)
+    function_definitions = [
+        node for node in module.body if isinstance(node, ast.FunctionDef)
+    ]
+    for fd in function_definitions:
+        if fd.name == "gpu_ostinato":
+            gpu_ostinato.__doc__ = ast.get_docstring(fd)
+
+    # Fix GPU-AAMP-OSTINATO Docs
+    gpu_aamp_ostinato.__doc__ = ""
+    filepath = pathlib.Path(__file__).parent / "gpu_aamp_ostinato.py"
+
+    file_contents = ""
+    with open(filepath, encoding="utf8") as f:
+        file_contents = f.read()
+    module = ast.parse(file_contents)
+    function_definitions = [
+        node for node in module.body if isinstance(node, ast.FunctionDef)
+    ]
+    for fd in function_definitions:
+        if fd.name == "gpu_aamp_ostinato":
+            gpu_aamp_ostinato.__doc__ = ast.get_docstring(fd)
+
     # Fix GPU-MPDIST Docs
     gpu_mpdist.__doc__ = ""
     filepath = pathlib.Path(__file__).parent / "gpu_mpdist.py"
