@@ -214,10 +214,7 @@ def are_arrays_equal(a, b):  # pragma: no cover
     if id(a) == id(b):
         return True
 
-    if a.shape != b.shape:
-        return False
-
-    return ((a == b) | (np.isnan(a) & np.isnan(b))).all()
+    return np.array_equal(a, b, equal_nan=True)
 
 
 def are_distances_too_small(a, threshold=10e-6):  # pragma: no cover
@@ -247,15 +244,20 @@ def are_distances_too_small(a, threshold=10e-6):  # pragma: no cover
     return False
 
 
-def check_window_size(m):
+def check_window_size(m, max_size=None):
     """
-    Check the window size and ensure that it is greater than or equal to 3
+    Check the window size and ensure that it is greater than or equal to 3 and, if
+    `max_size` is provided, ensure that the window size is less than or equal to the
+    `max_size`
 
     Parameters
     ----------
     m : int
         Window size
 
+    max_size : int, default None
+        The maximum window size allowed
+
     Returns
     -------
     None
@@ -274,6 +276,9 @@ def check_window_size(m):
             """,
         )
 
+    if max_size is not None and m > max_size:
+        raise ValueError(f"The window size must be less than or equal to {max_size}")
+
 
 def sliding_dot_product(Q, T):
     """
@@ -979,6 +984,12 @@ def mass(Q, T, M_T=None, Σ_T=None):
     if T.ndim != 1:  # pragma: no cover
         raise ValueError(f"T is {T.ndim}-dimensional and must be 1-dimensional. ")
 
+    if m > n:  # pragma: no cover
+        raise ValueError(
+            f"The length of `Q` ({len(Q)}) must be less than or equal to "
+            f"the length of `T` ({len(T)}). "
+        )
+
     distance_profile = np.empty(n - m + 1)
     if np.any(~np.isfinite(Q)):
         distance_profile[:] = np.inf
@@ -1104,6 +1115,12 @@ def mass_absolute(Q, T):
     if T.ndim != 1:  # pragma: no cover
         raise ValueError(f"T is {T.ndim}-dimensional and must be 1-dimensional. ")
 
+    if m > n:  # pragma: no cover
+        raise ValueError(
+            f"The length of `Q` ({len(Q)}) must be less than or equal to "
+            f"the length of `T` ({len(T)}). "
+        )
+
     distance_profile = np.empty(n - m + 1)
     if np.any(~np.isfinite(Q)):
         distance_profile[:] = np.inf
@@ -1238,6 +1255,7 @@ def preprocess(T, m):
     T = transpose_dataframe(T)
     T = np.asarray(T)
     check_dtype(T)
+    check_window_size(m, max_size=T.shape[-1])
 
     T[np.isinf(T)] = np.nan
     M_T, Σ_T = compute_mean_std(T, m)
@@ -1277,6 +1295,7 @@ def preprocess_non_normalized(T, m):
     T = transpose_dataframe(T)
     T = np.asarray(T)
     check_dtype(T)
+    check_window_size(m, max_size=T.shape[-1])
 
     T[np.isinf(T)] = np.nan
     T_subseq_isfinite = rolling_isfinite(T, m)
