@@ -836,7 +836,7 @@ def mstump(T, m, include=None, discords=False):
         err = f"T is {T_A.ndim}-dimensional and must be at least 1-dimensional"
         raise ValueError(f"{err}")
 
-    core.check_window_size(m)
+    core.check_window_size(m, max_size=min(T_A.shape[1], T_B.shape[1]))
 
     if include is not None:
         include = _preprocess_include(include)
